==> fle-cli-3.7.0.tgz: package/bin/fle-build.js <==
#!/usr/bin/env node

'use strict';

// var fs = require('fs');
var path = require('path');
var program = require('commander');
// var chalk = require('chalk');
var homeFlePath = require('../lib/consts').homeFlePath;
var utils = require('../lib/utils');

// 检查是否为fle项目
var typeOpts = utils.checkProject();

program
	.usage('[options]')
	.option('-u, --upload', 'upload files to cdn (just for webpack)')
	.on('--help', () => {
		console.log();
	})
	.parse(process.argv);

var opts = program.opts();
var env = Object.assign({
	NODE_ENV: 'production',
	PROJECT_ROOT_PATH: process.cwd(),
	FLE_FRAMEWORK: typeOpts.framework,
	FLE_UPLOAD: opts.upload,
	FLE_UPLOAD_CONFIG: opts.upload ? JSON.stringify(require(path.join(homeFlePath, '.cdn.json'))) : ''
}, process.env);
var rimrafPath = path.join(__dirname, '../node_modules/.bin/rimraf');

if (typeOpts.compiler === 'rollup') {
	// 清空先前编译的文件
	utils.spawn(
		rimrafPath,
		[
			path.resolve('public/dist')
		],
		{
			stdio: 'inherit'
		}
	);

	// demo
	utils.spawn(
		path.join(homeFlePath, 'node_modules/.bin/rollup'),
		[
			'-c',
			path.join(homeFlePath, 'build/rollup/rollup.config.js'),
		],
		{
			cwd: homeFlePath,
			stdio: 'inherit',
			env: env
		}
	);
} else if (typeOpts.compiler === 'webpack') {
	// 清空先前编译的文件
	// utils.spawn(
	// 	rimrafPath,
	// 	[
	// 		path.resolve('dist')
	// 	],
	// 	{
	// 		stdio: 'inherit'
	// 	}
	// );

	// build
	utils.spawn(
		path.join(homeFlePath, 'node_modules/.bin/webpack'),
		[
			'--progress',
			'--hide-modules',
			'--config',
			path.join(homeFlePath, 'build/webpack/webpack.build.config.js')
		],
		{
			cwd: homeFlePath,
			stdio: 'inherit',
			env: env
		}
	);
}

==> fle-cli-3.10.8.tgz: package/bin/fle-build.js <==
#!/usr/bin/env node

'use strict';

var fs = require('fs');
var path = require('path');
var program = require('commander');
// var chalk = require('chalk');
var homeFlePath = require('../lib/consts').homeFlePath;
var utils = require('../lib/utils');

// 检查是否为fle项目
var typeOpts = utils.checkProject();

program
	.usage('[options] <pages>')
	.option('-u, --upload', 'upload files to cdn (just for webpack)')
	.on('--help', () => {
		console.log();
    console.log('  Description:');
    console.log();
		console.log('    It will compile all pages from src by default');
		console.log('    And you can specify pages that should be compiled');
		console.log('    For example: $ fle build index home');
		console.log('    So [src/index] and [src/home] will be compiled');
		console.log('    Have fun with it!');
		console.log();
	})
	.parse(process.argv);

var opts = program.opts();
var cdnFile = path.join(homeFlePath, '.cdn.json');
var env = Object.assign({
	NODE_ENV: 'production',
	PROJECT_ROOT_PATH: process.cwd(),
	FLE_FRAMEWORK: typeOpts.framework,
	FLE_UPLOAD: opts.upload,
	FLE_UPLOAD_CONFIG: (opts.upload && fs.existsSync(cdnFile)) ? JSON.stringify(require(cdnFile)) : '',
	FLE_COMPILE_PAGES: program.args.join(',')
}, process.env);
var rimrafPath = path.join(__dirname, '../node_modules/.bin/rimraf');

if (typeOpts.compiler === 'rollup') {
	// 清空先前编译的文件
	utils.spawn(
		rimrafPath,
		[
			path.resolve('public/dist')
		],
		{
			stdio: 'inherit'
		}
	);

	// demo
	utils.spawn(
		path.join(homeFlePath, 'node_modules/.bin/rollup'),
		[
			'-c',
			path.join(homeFlePath, 'build/rollup/rollup.config.js'),
		],
		{
			cwd: homeFlePath,
			stdio: 'inherit',
			env: env
		}
	);
} else if (typeOpts.compiler === 'webpack') {
	// 清空先前编译的文件
	// utils.spawn(
	// 	rimrafPath,
	// 	[
	// 		path.resolve('dist')
	// 	],
	// 	{
	// 		stdio: 'inherit'
	// 	}
	// );

	// build
	utils.spawn(
		path.join(homeFlePath, 'node_modules/.bin/webpack'),
		[
			'--progress',
			'--hide-modules',
			'--config',
			path.join(homeFlePath, 'build/webpack/webpack.build.config.js')
		],
		{
			cwd: homeFlePath,
			stdio: 'inherit',
			env: env
		}
	);
}
